import Vue from 'vue';
import { default as Router, Route } from 'vue-router';

import Dashboard from '@/views/Dashboard.vue';
import Login from '@/views/Login.vue';
import Measures from '@/views/Measures.vue';
import UserAccount from '@/views/UserAccount.vue';
import QuickPanels from '@/views/QuickPanels.vue';

import userService from '@/services/user';

Vue.use(Router);

const router = new Router({
  mode: 'history',
  base: process.env.BASE_URL,
  routes: [
    {
      path: '/',
      redirect: '/dashboard'
    },
    {
      path: '/login',
      name: 'login',
      component: Login
    },
    {
      path: '/dashboard',
      name: 'dashboard',
      component: Dashboard,
      meta: { requiresAuth: true }
    },
    {
      path: '/measures',
      name: 'measures',
      component: Measures,
      meta: { requiresAuth: true }
    },
    {
      path: '/user-account',
      name: 'user-account',
      component: UserAccount,
      meta: { requiresAuth: true }
    },
    {
      path: '/quick-panels',
      name: 'quick-panels',
      component: QuickPanels,
      meta: { requiresAuth: true }
    }
  ]
});

// Auth filter
router.beforeEach((to, from, next) => {
  if (to.matched.some((record) => record.meta.requiresAuth)) {
    if (!userService.isAuthed()) {
      next({
        path: '/login',
        params: { nextUrl: to.fullPath } });
    } else { next(); } // if authed
  } else { next(); } // if auth required
});

export default router;
