/*tslint:disable:no-console*/
import { LogMessage, LogLevel} from './log-message';
import Logger from './logger';
import LogAppender from './log-appender';

export class ConsoleAppender implements LogAppender {
  constructor(public threshold?: LogLevel) {}

  public appendMessage(logger: Logger, msg: LogMessage): void {
    if (this.threshold && msg.level < this.threshold) { return; }

    let logMethod = console.log;
    switch (msg.level) {
      case LogLevel.ALL:    logMethod = console.trace; break;
      case LogLevel.DEBUG:  logMethod = console.debug; break;
      case LogLevel.INFO:   logMethod = console.info; break;
      case LogLevel.WARN:   logMethod = console.warn; break;
      case LogLevel.ERROR:
      case LogLevel.FATAL:  logMethod = console.trace; break;
    }

    if (msg.error) {
      logMethod(logger.name, msg.message, msg.error);
    } else {
      logMethod(logger.name, msg.message, msg.stacktrace);
    }
  }
}

export default ConsoleAppender;
