import User from '@/models/user.ts';
import { default as apiClient, PmApiClient } from '@/services/pm-api-client.ts';

export class UserService {
  private user?: User = undefined;

  constructor(private api: PmApiClient) { }

  public isAuthed(): boolean {
    return this.user != null && this.user.authToken != null;
  }

  public getUser(): User | undefined { return this.user; }

  public authUser(email: string, password: string): Promise<User> {
    return this.api.createAuthToken(email, password)
      .then((token) =>  this.api.getUser(token));
  }

  public getUserById(reqUserId: string): Promise<User> {
    if (this.user == null) {
      return Promise.reject(new Error('no currently authenticated user'));
    } else {
      return this.api.getUserById(this.user, reqUserId);
    }
  }
}

export default new UserService(apiClient);
